Powermat iPhone 5 5S Wireless Charging Pads, Cases, Rings | Duracell Powermat
Description: iPhone 5 wireless charging pad, battery charger case and portable backup battery power. Buy wireless charger for iPhone 5 and iPhone 5s and more from Duracell Powermat.
Keywords: iphone 5, iphone 5s, iphone5, iphone 5 charger

# Duracell Powermat

## Refine Your Results By:

Browse
iPhone 5 / 5s
14 Products
Filter By
Sort By
Name A-Z
14 Products Results

14 Products
Filter By
Sort By
Name A-Z
14 Products Results
My Comparisons

- Remove
  1
- Remove
  2
- Remove
  3
- Remove
  4

Compare Reset

## Refine Your Results By:

Shop Duracell Powermat
Recommended products Recently viewed

Back to Top

#### Relax, It's Charging

Have the power to do more with your phone this year. Stay Charged, Anytime, Anywhere with Duracell Powermat.